==> gtk-sharp_1.0.2.orig.tar.gz: gtk-sharp-1.0.2/glib/Idle.cs <==
// GLib.Idle.cs - Idle class implementation
//
// Author: Mike Kestner <mkestner@speakeasy.net>
//         Rachel Hestilow <hestilow@ximian.com>
//
// Copyright (c) 2002 Mike Kestner
// Copyright (c) Rachel Hestilow
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of version 2 of the Lesser GNU General 
// Public License as published by the Free Software Foundation.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public
// License along with this program; if not, write to the
// Free Software Foundation, Inc., 59 Temple Place - Suite 330,
// Boston, MA 02111-1307, USA.


namespace GLib {

	using System;
	using System.Runtime.InteropServices;

	public delegate bool IdleHandler ();

	public class Idle {

		internal class IdleProxy : SourceProxy {
			public IdleProxy (IdleHandler real)
			{
				real_handler = real;
				proxy_handler = new IdleHandler (Handler);
			}

			public bool Handler ()
			{
				IdleHandler idle_handler = (IdleHandler) real_handler;

				bool cont = idle_handler ();
				if (!cont)
					Remove ();
				return cont;
			}
		}
		
		private Idle ()
		{
		}
		
		[DllImport("libglib-2.0-0.dll")]
		static extern uint g_idle_add (IdleHandler d, IntPtr data);

		public static uint Add (IdleHandler hndlr)
		{
			IdleProxy p = new IdleProxy (hndlr);
			uint code = g_idle_add ((IdleHandler) p.proxy_handler, IntPtr.Zero);
			Source.source_handlers [code] = p;

			return code;
		}
		
		[DllImport("libglib-2.0-0.dll")]
		static extern bool g_source_remove_by_funcs_user_data (IdleHandler d, IntPtr data);
                                                                                
		public static bool Remove (IdleHandler hndlr)
		{
			foreach (int code in Source.source_handlers.Keys){
				IdleProxy p = (IdleProxy) Source.source_handlers [code];
				
				if (p.real_handler == hndlr)
					Source.source_handlers.Remove (p);
			}
			return g_source_remove_by_funcs_user_data (hndlr, IntPtr.Zero);
		}
	}
}

==> gtk-sharp_1.0.4.orig.tar.gz: gtk-sharp-1.0.4/glib/Idle.cs <==
// GLib.Idle.cs - Idle class implementation
//
// Author: Mike Kestner <mkestner@speakeasy.net>
//         Rachel Hestilow <hestilow@ximian.com>
//
// Copyright (c) 2002 Mike Kestner
// Copyright (c) Rachel Hestilow
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of version 2 of the Lesser GNU General 
// Public License as published by the Free Software Foundation.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public
// License along with this program; if not, write to the
// Free Software Foundation, Inc., 59 Temple Place - Suite 330,
// Boston, MA 02111-1307, USA.


namespace GLib {

	using System;
	using System.Runtime.InteropServices;

	public delegate bool IdleHandler ();

	public class Idle {

		internal class IdleProxy : SourceProxy {
			public IdleProxy (IdleHandler real)
			{
				real_handler = real;
				proxy_handler = new IdleHandler (Handler);
			}

			public bool Handler ()
			{
				IdleHandler idle_handler = (IdleHandler) real_handler;

				bool cont = idle_handler ();
				if (!cont)
					Remove ();
				return cont;
			}
		}
		
		private Idle ()
		{
		}
		
		[DllImport("libglib-2.0-0.dll")]
		static extern uint g_idle_add (IdleHandler d, IntPtr data);

		public static uint Add (IdleHandler hndlr)
		{
			IdleProxy p = new IdleProxy (hndlr);
			uint code = g_idle_add ((IdleHandler) p.proxy_handler, IntPtr.Zero);
			Source.source_handlers [code] = p;

			return code;
		}
		
		[DllImport("libglib-2.0-0.dll")]
		static extern bool g_source_remove_by_funcs_user_data (IdleHandler d, IntPtr data);
                                                                                
		public static bool Remove (IdleHandler hndlr)
		{
			foreach (uint code in Source.source_handlers.Keys){
				IdleProxy p = (IdleProxy) Source.source_handlers [code];
				
				if (p.real_handler == hndlr)
					Source.source_handlers.Remove (p);
			}
			return g_source_remove_by_funcs_user_data (hndlr, IntPtr.Zero);
		}
	}
}
